pub struct AnalysisMetadata { /* private fields */ }Expand description
Metadata needed to interpret one live Analysis snapshot.
Implementations
Sourceimpl AnalysisMetadata
impl AnalysisMetadata
pub fn new( sample_rate: f32, fft_size: u32, min_decibels: f32, max_decibels: f32, smoothing: f64, ) -> Self
Sourcepub fn sample_rate(self) -> f32
pub fn sample_rate(self) -> f32
Effective sample rate of the audio graph, in hertz.
Sourcepub fn frequency_bin_count(self) -> u32
pub fn frequency_bin_count(self) -> u32
Number of frequency values in each snapshot.
Sourcepub fn frequency_bin_width(self) -> f32
pub fn frequency_bin_width(self) -> f32
Width of each frequency bin, in hertz.
Sourcepub fn frequency_for_bin(self, bin: u32) -> Option<f32>
pub fn frequency_for_bin(self, bin: u32) -> Option<f32>
Center frequency represented by bin, or None when it is out of range.
pub fn min_decibels(self) -> f32
pub fn max_decibels(self) -> f32
Sourcepub fn decibels_for_frequency_value(self, value: f32) -> f32
pub fn decibels_for_frequency_value(self, value: f32) -> f32
Convert a normalized byte-frequency value to its configured decibel value.