pub fn PlaybackStopButton(_: PlaybackStopButtonProps) -> ElementExpand description
A native button that stops Playback and resets its position.
Props
For details, see the props struct definition.
controller:AudioPlayerControllerlabel:String
pub fn PlaybackStopButton(_: PlaybackStopButtonProps) -> ElementA native button that stops Playback and resets its position.
For details, see the props struct definition.
controller : AudioPlayerControllerlabel : String