pub struct DecodedAudio { /* private fields */ }Expand description
Immutable Decoded Audio backed by one flat-planar sample allocation.
Clones share the same sample storage.
Implementations
Sourceimpl DecodedAudio
impl DecodedAudio
Sourcepub fn from_planar(
samples: Vec<f32>,
channels: usize,
sample_rate: f32,
) -> Result<Self, DecodedAudioError>
pub fn from_planar( samples: Vec<f32>, channels: usize, sample_rate: f32, ) -> Result<Self, DecodedAudioError>
Consume flat channel-major samples with an equal positive frame count.
pub fn channel_count(&self) -> usize
pub fn frame_count(&self) -> usize
Sourcepub fn sample_rate(&self) -> f32
pub fn sample_rate(&self) -> f32
Effective sample rate of the decode context, in hertz.
Sourcepub fn duration(&self) -> Duration
pub fn duration(&self) -> Duration
Duration derived from frame count and effective sample rate.
pub fn channel(&self, index: usize) -> Option<&[f32]>
pub fn channels(&self) -> impl ExactSizeIterator<Item = &[f32]>