#[non_exhaustive]pub enum BoundedPlaybackFailure {
SeekTimedOut,
ActivationRejected,
PauseRejected,
}Expand description
A failure scoped to one Bounded Playback operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SeekTimedOut
The browser did not confirm the seek to the selected start.
ActivationRejected
The browser rejected activation after the bounded seek completed.
PauseRejected
The browser rejected a pause required by the bounded operation.