BoundedPlaybackPhase

Enum BoundedPlaybackPhase 

#[non_exhaustive]
pub enum BoundedPlaybackPhase { Seeking, Activating, Active, Paused, Retargeting, Wrapping, Completed, Cancelled, Failed(BoundedPlaybackFailure), }
The observable lifecycle of one Bounded Playback operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Seeking

Playback is paused while seeking to the selected start.



Activating

The seek completed and Playback is awaiting browser play confirmation.



Active

The browser confirmed Playback and the selected end is being enforced.



Paused

Playback is paused while retaining the selected range for resume.



Retargeting

A committed selection edit requires a seek to the new range start.



Wrapping

A loop boundary is seeking back to the selected range start.



Completed

The one-shot operation stopped and clamped observable position to its end.



Cancelled

The application explicitly cancelled the bounded operation.



Failed(BoundedPlaybackFailure)

The bounded operation failed without failing its Playback Source.

Implementations

Source

impl BoundedPlaybackPhase

pub fn is_enforcing(self) -> bool

Whether this phase still owns future Playback transport behavior.