#[non_exhaustive]pub enum PlaybackGraphState {
NotRequested,
AwaitingSource,
Preparing,
Suspended,
Running,
InteractionRequired,
Unavailable,
}Expand description
The state of an opt-in owner-lifetime Playback graph.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotRequested
This Playback owner uses ordinary direct media playback.
AwaitingSource
The graph is waiting for an eligible Playback Source.
Preparing
The graph is being created or attached to the current source.
Suspended
The graph exists but its audio context is suspended.
Running
The graph is running with the current source attached.
InteractionRequired
Playback needs another user interaction before graph output can resume.
Graph setup failed permanently for this owner; transport degraded to direct Playback.