#[non_exhaustive]pub enum PlaybackLoadingPolicy {
Eager,
OnPlay,
}Expand description
When Playback attaches the current source to its media resource.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Eager
Begin acquiring the source as soon as it becomes current.
OnPlay
Keep the source dormant until Playback is requested.