#[non_exhaustive]pub enum PlaybackNetworkActivity {
Inactive,
Unknown,
Loading,
Idle,
Stalled,
}Expand description
Coarse network activity for the current Playback Source attempt.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Inactive
No URL-addressable Playback Source is attached.
Unknown
A URL-addressable Playback Source is attached but has no reported activity yet.
Loading
The browser reports that it is acquiring media data.
Idle
The browser is not currently acquiring media data.
Stalled
Media acquisition has stopped unexpectedly without becoming a terminal failure.