pub struct RecordingChunkDelivery {
pub cadence: Duration,
/* private fields */
}Expand description
Opt-in cadence and callback for ordered Recording Chunk delivery.
Fields
cadence: DurationApproximate interval at which the browser should create chunk boundaries.
Boundaries may be empty, late, or dependent on earlier fragments.
Implementations
Sourceimpl RecordingChunkDelivery
impl RecordingChunkDelivery
Sourcepub fn new(
cadence: Duration,
on_chunk: impl FnMut(RecordingChunk) + 'static,
) -> Self
pub fn new( cadence: Duration, on_chunk: impl FnMut(RecordingChunk) + 'static, ) -> Self
Configure ordered push delivery at an approximate cadence.