pub struct RecordingChunkDeliveryFailure { /* private fields */ }Expand description
The terminal failure of incremental Recording Chunk delivery.
Capture and final Recorded Audio assembly continue independently after this failure, but this Recording will deliver no later chunks.
Implementations
Sourceimpl RecordingChunkDeliveryFailure
impl RecordingChunkDeliveryFailure
pub fn recording_id(&self) -> RecordingId
pub fn failed_sequence(&self) -> u64
pub fn error(&self) -> &AudioError