pub struct WaveformBucketSpan { /* private fields */ }Expand description
An exact positive source-time bucket span expressed as a duration ratio.
Explicit levels use a divisor of one. Peaks conversion may need a larger divisor when its evenly spaced span is not an integral number of nanoseconds.
Implementations