pub fn InteractiveWaveform(_: InteractiveWaveformProps) -> ElementExpand description
Present Playback position and one controlled Waveform Selection over Waveform Data.
The three interactions remain native sliders. Pointer movement is presented as an
internal draft and is committed through the Controller or on_selection_change
when the native interaction completes.
Props
For details, see the props struct definition.
data:WaveformDatacontroller:AudioPlayerControllerselection:WaveformSelectionon_selection_change:EventHandler<WaveformSelection>bucket_budget:usizeheight:f64fine_step_secs:f64coarse_step_secs:f64label:Stringplayback_label:Stringselection_start_label:Stringselection_end_label:String